﻿using Infragistics.Controls.Menus;
using Infragistics.Windows;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace DataTreeSelectionWidth
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            OtherTree.ItemsSource = new SampleData();
        }
    }

    public class SampleData : ObservableCollection<ParentNode>
    {
        public SampleData()
        {
            ParentNode p1 = new ParentNode { Name = "Profitability", Children = new ObservableCollection<ChildNode>() };
            ParentNode p2 = new ParentNode { Name = "Growth", Children = new ObservableCollection<ChildNode>() };
            ParentNode p3 = new ParentNode { Name = "Efficiency", SubParents = new ObservableCollection<ParentNode>(), Children = new ObservableCollection<ChildNode>() };
            ParentNode p4 = new ParentNode { Name = "Investment", Children = new ObservableCollection<ChildNode>() };
            ParentNode p5 = new ParentNode { Name = "Capital Strength", Children = new ObservableCollection<ChildNode>() };
            ParentNode p6 = new ParentNode { Name = "Quality", Children = new ObservableCollection<ChildNode>() };
            ParentNode p7 = new ParentNode { Name = "Upwards", Children = new ObservableCollection<ChildNode>() };

            p1.Children.Add(new ChildNode() { Parent = p1});
            p2.Children.Add(new ChildNode() { Parent = p2});
            p4.Children.Add(new ChildNode() { Parent = p4});
            p5.Children.Add(new ChildNode() { Parent = p5});
            p6.Children.Add(new ChildNode() { Parent = p6});
                       
            p7.Children.Add(new ChildNode { Parent = p7, Name = "Days sales outstanding", Value = 1, Average = 64.3, StandardDeviation = 32.6, Percent = 1.0 });
            p7.Children.Add(new ChildNode { Parent = p7, Name = "Days payables outstanding", Value = 1, Average = 70.8, StandardDeviation = 84.2, Percent = 0.8 });
            p7.Children.Add(new ChildNode { Parent = p7, Name = "Inventory turnover, days", Value = 1, Average = 6.4, StandardDeviation = 15.3, Percent = 0.7 });
            p7.Children.Add(new ChildNode { Parent = p7, Name = "NWI / Sales", Value = 1, Average = 0.1, StandardDeviation = 0.1, Percent = 0.9 });
            p7.Children.Add(new ChildNode { Parent = p7, Name = "Asset turnover", Value = 1, Average = 0.7, StandardDeviation = 0.3, Percent = 0.0 });
            p3.SubParents.Add(p7);

            this.Add(p1);
            this.Add(p2);
            this.Add(p7);
            this.Add(p4);
            this.Add(p5);
            this.Add(p6);
        }
    }

    public class ParentNode : ObservableModel
    {
        public string Name { get; set; }

        public ObservableCollection<ParentNode> SubParents { get; set; }

        public ObservableCollection<ChildNode> Children { get; set; }

        public bool? IsSelected { get; set; }

        private bool _isChecked;

        public bool IsChecked
        {
            get { return _isChecked; }
            set
            {
                _isChecked = value;
                OnPropertyChanged("IsChecked");
            }
        }
    }

    public class ChildNode : ObservableModel
    {
        public string Name { get; set; }

        public double Value { get; set; }

        public double Average { get; set; }

        public double StandardDeviation { get; set; }

        public double Percent { get; set; }

        public bool? IsSelected { get; set; }

        public bool IsChecked
        {
            get { return _isChecked; }
            set { _isChecked = value;
                Parent.IsChecked = _isChecked;
                OnPropertyChanged("IsChecked");
            }
        }

        private bool _isChecked;

        public ParentNode Parent { get; set; }
    }

    public class ObservableModel : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        protected void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
